@@ -276,133 +276,10 @@ class SFNScope:
         for handler in stmt.handlers:
             child_scope = ChildScope(self)
             result_path = None
-            h_chain, h_n = child_scope.handle_body(handler.body)
             if handler.name:
                 result_path = f"$.register.{handler.name}"
                 child_scope.add_var(handler.name)
-                if h_chain:
-                    process_exception = sfn.Pass(
-                        self.cdk_stack,
-                        self.state_name(f"Interpret {handler.name}"),
-                        input_path="$.register",
-                        parameters=child_scope.build_register_assignment(
-                            {
-                                handler.name: JsonPath.string_at(
-                                    f"States.StringToJson($.{handler.name}.Cause)"
-                                )
-                            }
-                        ),
-                        result_path="$.register",
-                    )
-                    process_exception_choice = sfn.Choice(
-                        self.cdk_stack,
-                        self.state_name(f"Interpret Choice {handler.name}"),
-                    )
-                    process_exception_cause = sfn.Pass(
-                        self.cdk_stack,
-                        self.state_name(f"Interpret {handler.name}"),
-                        input_path="$.register",
-                        parameters=child_scope.build_register_assignment(
-                            {
-                                handler.name: {
-                                    "Cause": JsonPath.string_at(
-                                        f"States.StringToJson($.{handler.name}.Cause)"
-                                    ),
-                                    "Error": JsonPath.string_at(
-                                        f"$.{handler.name}.Error"
-                                    ),
-                                    "ExecutionArn": JsonPath.string_at(
-                                        f"$.{handler.name}.ExecutionArn"
-                                    ),
-                                    "Name": JsonPath.string_at(
-                                        f"$.{handler.name}.Name"
-                                    ),
-                                    "Status": JsonPath.string_at(
-                                        f"$.{handler.name}.Status"
-                                    ),
-                                }
-                            }
-                        ),
-                        result_path="$.register",
-                    )
-                    format_string = "{}{}"
-                    split = "{"
-                    process_exception_malformed_cause = sfn.Pass(
-                        self.cdk_stack,
-                        self.state_name(f"Interpret {handler.name}"),
-                        input_path="$.register",
-                        parameters=child_scope.build_register_assignment(
-                            {
-                                handler.name: {
-                                    "Cause": JsonPath.string_at(
-                                        f"States.StringToJson(States.Format('{format_string}', '{split}', States.ArrayGetItem(States.StringSplit($.{handler.name}.Cause, '{split}'), 1)))"
-                                    ),
-                                    "Error": JsonPath.string_at(
-                                        f"$.{handler.name}.Error"
-                                    ),
-                                    "ExecutionArn": JsonPath.string_at(
-                                        f"$.{handler.name}.ExecutionArn"
-                                    ),
-                                    "Name": JsonPath.string_at(
-                                        f"$.{handler.name}.Name"
-                                    ),
-                                    "Status": JsonPath.string_at(
-                                        f"$.{handler.name}.Status"
-                                    ),
-                                }
-                            }
-                        ),
-                        result_path="$.register",
-                    )
-                    process_exception_default = sfn.Pass(
-                        self.cdk_stack,
-                        self.state_name(f"Interpret {handler.name}"),
-                        input_path="$.register",
-                        parameters=child_scope.build_register_assignment(
-                            {
-                                handler.name: {
-                                    "ExecutionArn": JsonPath.string_at(
-                                        f"$.{handler.name}.ExecutionArn"
-                                    ),
-                                    "Name": JsonPath.string_at(
-                                        f"$.{handler.name}.Name"
-                                    ),
-                                    "Status": JsonPath.string_at(
-                                        f"$.{handler.name}.Status"
-                                    ),
-                                }
-                            }
-                        ),
-                        result_path="$.register",
-                    )
-                    process_exception.next(process_exception_choice)
-                    process_exception_choice.when(
-                        sfn.Condition.and_(
-                            sfn.Condition.is_present(
-                                f"$.register.{handler.name}.Cause"
-                            ),
-                            sfn.Condition.string_matches(
-                                f"$.register.{handler.name}.Cause",
-                                "The cause could not be determined*",
-                            ),
-                        ),
-                        process_exception_malformed_cause,
-                    )
-                    process_exception_choice.when(
-                        sfn.Condition.is_present(f"$.register.{handler.name}.Cause"),
-                        process_exception_cause,
-                    )
-                    process_exception_choice.otherwise(process_exception_default)
-                    process_exception_cause.next(h_chain[0])
-                    process_exception_malformed_cause.next(h_chain[0])
-                    process_exception_default.next(h_chain[0])
-                    h_chain = [
-                        process_exception,
-                        process_exception_choice,
-                        process_exception_cause,
-                        process_exception_malformed_cause,
-                        process_exception_default,
-                    ] + h_chain
+            h_chain, h_n = child_scope.handle_body(handler.body)
 
             # If the handler body isn't empty, add it in
             if h_chain:
